@@ -32,13 +32,13 @@ public:
         void destroyed(int size);
     };
 private:
-    std::auto_ptr<Strategy> m_strategy;
+    std::unique_ptr<Strategy> m_strategy;
     State m_state;
 public:
     SmartAI(Sea::Player player, Sea* sea, bool random, const BattleShipsConfiguration* config);
 
-    virtual Coord getMove();
-    virtual void notify(Sea::Player player, const Coord& c, const HitInfo& hit);
+    Coord getMove() override;
+    void notify(Sea::Player player, const Coord& c, const HitInfo& hit) override;
 };
 
 #endif // SMARTAI_H
